@@ -95,13 +95,17 @@ class Report:
             self.upload()
         return sec
             
-    def upload(self, force=False, display_level=10, hide={}):
+    def upload(self, force=False, display_level=10, hide={}, filename=None):
+
+        if filename is None:
+            filename = self.filename
+
         if (self.upload_on_set_content and datetime.datetime.now() > self.last_upload_time + datetime.timedelta(seconds=self.debound_upload)) or force:
-            self.save(display_level=display_level, hide=hide)
+            self.save(display_level=display_level, hide=hide, filename=filename)
             
             self.last_upload_time = datetime.datetime.now()
             
-            self.uploader(self.filename+'.html') 
+            self.uploader(filename+'.html')
             
     def render(self):
         if self.state:
@@ -145,15 +149,17 @@ class Report:
         else:
             return ""
     
-    def save(self, display_level=0, hide={}):
-        f_ = open(self.filename+'.html','w')
+    def save(self, display_level=0, hide={}, filename=None):
+        if filename is None:
+            filename = self.filename
+        f_ = open(filename+'.html','w')
 
         f_.write(self.as_html(display_level=display_level, hide=hide))
         f_.close()
     
-    def finalize(self, display_level=0, hide={}):
+    def finalize(self, display_level=0, hide={}, filename=None):
         
-        self.upload(force=True, display_level=display_level, hide=hide)
+        self.upload(force=True, display_level=display_level, hide=hide, filename=filename)
 
         
             
